Found in the pandas documentation, this is valid:

* A pandas class (in the form ``:class:`pandas.Series```)
* A pandas method (in the form ``:meth:`pandas.Series.sum```)
* A pandas function (in the form ``:func:`pandas.to_datetime```)

it's documenting roles using code samples (double backticks).
